@@ -1,5 +1,6 @@
 from .audio_customization_param import AudioCustomizationParam
+from .audio_speech_chunk import AudioSpeechChunk
 from .audio_speech_params import AudioSpeechParams
 from .transcriptions_create_param import TranscriptionsParam
 
-__all__ = ['AudioSpeechParams', 'AudioCustomizationParam', 'TranscriptionsParam']
+__all__ = ['AudioSpeechParams', 'AudioCustomizationParam', 'TranscriptionsParam', 'AudioSpeechChunk']
